# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Anna Wojdel <awojdel@fluendo.com>


API_SERVER = 'api.grooveshark.com'
API_PATH = '/ws/1.0/?json'

ELISA_AUTH_SERVER = 'www.moovida.com'
ELISA_AUTH_PATH = 'services/grooveshark/session_start/'

IMG_SERVER = 'beta.grooveshark.com'
LOCAL_SERVER = 'grooveshark://'

# Below are dictionaries used to construct JSON RPC calls to Grooveshark.
SESSION_DESTROY_REQ = { "method": "session.destroy",
                        "header": {"sessionID": None} }
SESSION_LOGIN_REQ = { "method": "session.login", 
                      "parameters": { "username": None, 
                                      "password": None }, 
                      "header": { "sessionID": None} }
SESSION_LOGOUT_REQ = { "method": "session.logout", 
                       "header": { "sessionID": None} }
POPULAR_GETSONGS_REQ = { "method": "popular.getSongs", 
                         "parameters": { "limit": "", 
                                         "page": "" }, 
                         "header": { "sessionID": None } }
POPULAR_GETARTISTS_REQ = { "method": "popular.getArtists", 
                           "parameters": { "limit": "",
                                           "page": ""}, 
                           "header": { "sessionID": None } }
POPULAR_GETALBUMS_REQ = { "method": "popular.getAlbums", 
                          "parameters": { "limit": "",
                                          "page": "" }, 
                          "header": { "sessionID": None } }
USER_GETFAVOURITESONGS_REQ = { "method": "user.getFavoriteSongs", 
                               "parameters": {"userID": None,
                                              "limit": "" }, 
                               "header": {"sessionID": None } }
USER_GETPLAYLISTS_REQ = { "method": "user.getPlaylists", 
                               "parameters": {"userID": None,
                                              "limit": "" }, 
                               "header": {"sessionID": None } }
ARTIST_GETSONGS_REQ = { "method": "artist.getSongs", 
                        "parameters": { "artistID": None, 
                                        "limit": "",
                                        "page": "" }, 
                        "header": { "sessionID": None } }
ALBUM_GETSONGS_REQ = { "method": "album.getSongs", 
                       "parameters": { "albumID": None, 
                                       "limit": "",
                                       "page": "" }, 
                       "header": { "sessionID": None } }
PLAYLIST_GETSONGS_REQ = { "method": "playlist.getSongs", 
                       "parameters": { "playlistID": None, 
                                       "limit": "",
                                       "page": "" }, 
                       "header": { "sessionID": None } }
PLAYLIST_ADDSONG_REQ = { "method": "playlist.addSong", 
                       "parameters": { "playlistID": None, 
                                       "songID": None,
                                       "position": None }, 
                       "header": { "sessionID": None } }
PLAYLIST_REMOVESONG_REQ = { "method": "playlist.removeSong", 
                       "parameters": { "playlistID": None, 
                                       "position": None }, 
                       "header": { "sessionID": None } }
SONG_GETSTREAMURL_REQ = { "method": "song.getStreamUrlEx", 
                          "parameters": { "songID": None }, 
                          "header": { "sessionID": None } }
SONG_FAVORITE_REQ = { "method": "song.favorite", 
                       "parameters": { "songID": None}, 
                       "header": { "sessionID": None } }
SONG_UNFAVORITE_REQ = { "method": "song.unfavorite", 
                       "parameters": { "songID": None}, 
                       "header": { "sessionID": None } }
SONG_ABOUT_REQ = { "method": "song.about", 
                          "parameters": { "songID": None }, 
                          "header": { "sessionID": None } }
SONG_PLAYBACKREACHED30SEC_REQ = { "method": "song.setPlaybackReached30Seconds", 
                          "parameters": { "streamKey": None,
                                          "streamServerID": None }, 
                          "header": { "sessionID": None } }
SEARCH_ARTISTS_REQ = { "method": "search.artists", 
                       "parameters": { "query": None, 
                                       "limit": "" }, 
                       "header": { "sessionID": None } }
SEARCH_ALBUMS_REQ = { "method": "search.albums", 
                      "parameters": { "query": None, 
                                      "limit": "" }, 
                      "header": { "sessionID": None } }
SEARCH_SONGS_REQ = { "method": "search.songs", 
                     "parameters": { "query": None, 
                                     "limit": "" }, 
                     "header": { "sessionID": None } }
AUTOPLAY_START_REQ = { "method": "autoplay.start", 
                     "parameters": { "songIDs": None }, 
                     "header": { "sessionID": None } }
AUTOPLAY_STOP_REQ = { "method": "autoplay.stop", 
                     "header": { "sessionID": None } }
AUTOPLAY_GETNEXTSONG_REQ = { "method": "autoplay.getNextSong", 
                     "header": { "sessionID": None } }
AUTOPLAY_SMILE_REQ = { "method": "autoplay.smile", 
                     "parameters": { "autoplaySongID": None}, 
                     "header": { "sessionID": None } }
AUTOPLAY_FROWN_REQ = { "method": "autoplay.frown", 
                     "parameters": { "autoplaySongID": None}, 
                     "header": { "sessionID": None } }

"""
This map contains tuples with 
( modeltype, requestdata )
for each URI 
"""
from elisa.plugins.grooveshark.models import *
from elisa.plugins.base.models.media import PlayableModel
URI_REQUEST_MAP = { \
'grooveshark:///login':                ( GroovesharkLoginModel ,         SESSION_LOGIN_REQ ),
'grooveshark:///logout':               ( DummyModel ,                    SESSION_LOGOUT_REQ  ),
'grooveshark:///popular/artists':      ( GroovesharkArtistsListModel ,   POPULAR_GETARTISTS_REQ  ), 
'grooveshark:///popular/albums':       ( GroovesharkAlbumsListModel ,    POPULAR_GETALBUMS_REQ ),
'grooveshark:///popular/songs':        ( GroovesharkTracksListModel ,    POPULAR_GETSONGS_REQ ),
'grooveshark:///user/playlists':       ( GroovesharkPlaylistsListModel , USER_GETPLAYLISTS_REQ ),
'grooveshark:///user/favorites':       ( GroovesharkTracksListModel ,    USER_GETFAVOURITESONGS_REQ ),
'grooveshark:///artist/songs':         ( GroovesharkTracksListModel ,    ARTIST_GETSONGS_REQ ),
'grooveshark:///album/songs':          ( GroovesharkTracksListModel ,    ALBUM_GETSONGS_REQ ),
'grooveshark:///song/stream':          ( PlayableModel ,                 SONG_GETSTREAMURL_REQ ),
'grooveshark:///song/favorite':        ( DummyModel ,                    SONG_FAVORITE_REQ ),
'grooveshark:///song/unfavorite':      ( DummyModel ,                    SONG_UNFAVORITE_REQ ),
'grooveshark:///song/reached30sec':    ( DummyModel,                     SONG_PLAYBACKREACHED30SEC_REQ ),
'grooveshark:///playlist/songs':       ( GroovesharkTracksListModel ,    PLAYLIST_GETSONGS_REQ ),
'grooveshark:///playlist/addsong':     ( DummyModel ,                    PLAYLIST_ADDSONG_REQ ),
'grooveshark:///playlist/removesong':  ( DummyModel ,                    PLAYLIST_REMOVESONG_REQ ),
'grooveshark:///search/artists':       ( GroovesharkArtistsListModel ,   SEARCH_ARTISTS_REQ ),
'grooveshark:///search/albums':        ( GroovesharkAlbumsListModel ,    SEARCH_ALBUMS_REQ ),
'grooveshark:///search/songs':         ( GroovesharkTracksListModel ,    SEARCH_SONGS_REQ ),
'grooveshark:///autoplay/start':       ( GroovesharkTrackModel ,         AUTOPLAY_START_REQ ),
'grooveshark:///autoplay/stop':        ( DummyModel ,                    AUTOPLAY_STOP_REQ ),
'grooveshark:///autoplay/getnextsong': ( GroovesharkTrackModel ,         AUTOPLAY_GETNEXTSONG_REQ ),  
'grooveshark:///autoplay/smile':       ( DummyModel ,                    AUTOPLAY_SMILE_REQ ),  
'grooveshark:///autoplay/frown':       ( DummyModel ,                    AUTOPLAY_FROWN_REQ ),  
}

