# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Anna Wojdel <awojdel@fluendo.com>

from elisa.plugins.search.searcher import Searcher
from elisa.core.media_uri import MediaUri
from elisa.core.utils import defer

from elisa.core.resource_manager import  ResourceProviderNotFound
from elisa.plugins.poblesec.search_controller import SearcherEntry

from elisa.plugins.grooveshark.models import GroovesharkArtistsListModel, \
                                            GroovesharkAlbumsListModel, \
                                            GroovesharkTracksListModel

from twisted.internet import task

class GroovesharkSearcher(Searcher):
    """
    This is the Searcher for grooveshark.
    """

    paths = ['music']
    provider_path = "elisa.plugins.grooveshark.resource_provider:GroovesharkResourceProvider"

    def search(self, uri, model):

        provider = self._query_provider()
        if provider is None:
            return defer.fail(ResourceProviderNotFound(self.provider_path))

        def fill_model(result_model, reference_list):
            reference_list.extend(result_model)
            return reference_list

        def send_search_query(result, search_uri, query_string):
            def return_list(result_model):
                if isinstance(result_model, GroovesharkArtistsListModel):
                    return result_model.artists
                elif isinstance(result_model, GroovesharkAlbumsListModel):
                    return result_model.albums
                elif isinstance(result_model, GroovesharkTracksListModel):
                    return result_model.tracks
                else:
                    raise NotImplementedError()

            result_model, dfr = provider.post(uri=search_uri, query=query_string)
            dfr.addCallback(return_list)
            return dfr

        def return_model(result, model):
            return model

        query_string = uri.filename
        base_search_uri = 'grooveshark:///search/'

        dfr = send_search_query(None, MediaUri(base_search_uri+'artists'), query_string)
        dfr.addCallback(fill_model, model.artists)
        dfr.addCallback(send_search_query, MediaUri(base_search_uri+'albums'), query_string)
        dfr.addCallback(fill_model, model.albums)
        dfr.addCallback(send_search_query, MediaUri(base_search_uri+'songs'), query_string)
        dfr.addCallback(fill_model, model.tracks)
        dfr.addCallback(return_model, model)

        return dfr


def grooveshark_search_result_decorator(controller):
    searcher = 'GroovesharkSearcher'
    title = 'Grooveshark Search Results'
    icon_resource = 'elisa.plugins.grooveshark.search'
    searcher_entry = SearcherEntry(searcher, title, icon_resource)
    controller.searchers.append(searcher_entry)
    return defer.succeed(None)
