# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Anna Wojdel <awojdel@fluendo.com>

from elisa.plugins.grooveshark.utils import get_grooveshark_provider
from elisa.plugins.grooveshark.actions import AuthenticationAction

from elisa.plugins.poblesec.login import LoginController
from elisa.plugins.poblesec.link import Link
from elisa.plugins.poblesec.plugins_settings import GenericSettingsController

from twisted.internet import defer

from elisa.core.utils.i18n import install_translation

_poblesec = install_translation('poblesec')
_ = install_translation('grooveshark')

def grooveshark_settings_decorator(controller):
    controller.append_plugin( 'grooveshark', 
                              _('Grooveshark'),
                              '/poblesec/grooveshark/settings' )
    return defer.succeed(None)


class GroovesharkSettingsController(GenericSettingsController):

    def populate_model(self):
        action = AuthenticationAction(self)
        action.connect('name-changed', self._action_name_changed_cb)
        model = [action,]
        return defer.succeed(model)

    def _action_name_changed_cb(self, *args):
        self.refresh()


class GroovesharkLoginController(LoginController):
    """
    Login controller for Grooveshark
    """
    
    def login(self, username, password):
        # Overridden from mother class.
        try:
            provider = get_grooveshark_provider()
        except ResourceProviderNotFound, error:
            return defer.fail(error)
        else:
            return provider.login(username, password)

    def success(self, result):
        # Overridden from mother class.
        browser = self.frontend.retrieve_controllers('/poblesec/browser')[0]
        paths = [('/poblesec/internet_menu', _poblesec('INTERNET MEDIA'), {}),
                 ('/poblesec/music/internet', _poblesec('Music'), {}),
                 ('/poblesec/grooveshark', _('Grooveshark'), {})]
        return browser.navigate(paths)
